@@ -4,10 +4,8 @@ library("sf")
 context("pass_args")
 
 test_that("Test, if pass_args works correctly?", {
-  testthat::skip_on_appveyor()
-  # testthat::skip_on_travis()
   testthat::skip_on_cran()
-
+  
   alg <- "grass7:r.slope.aspect"
   params <- pass_args(alg, elevation = dem, format = "degrees")
   # overall checks
@@ -25,7 +23,7 @@ test_that("Test, if pass_args works correctly?", {
   )
   # check verbal input conversion
   expect_identical(as.character(params$format), "0")
-
+  
   # check if a parameter was wrongly specified
   params <- try(pass_args(alg, elev = dem), silent = TRUE)
   expect_s3_class(params, "try-error")
@@ -35,10 +33,8 @@ test_that("Test, if pass_args works correctly?", {
 })
 
 test_that("Test, if multiple input works with pass_args?", {
-  testthat::skip_on_appveyor()
-  # testthat::skip_on_travis()
   testthat::skip_on_cran()
-
+  
   r <- raster(ncol = 100, nrow = 100)
   r1 <- crop(r, extent(-10, 11, -10, 11))
   r2 <- crop(r, extent(0, 20, 0, 20))
@@ -46,7 +42,7 @@ test_that("Test, if multiple input works with pass_args?", {
   r1[] <- 1:ncell(r1)
   r2[] <- 1:ncell(r2)
   r3[] <- 1:ncell(r3)
-
+  
   alg <- "grass7:r.patch"
   # params <- pass_args(alg, input = list(r1, r2, r3))  # must also work...
   # perfect, it does
@@ -67,7 +63,7 @@ test_that("Test, if multiple input works with pass_args?", {
   
   # also write a test for shapefiles -> find a function that takes multiple
   # shapefiles as input (ParameterMultipleInput), e.g., grass7:v.patch
-
+  
   coords_1 <- matrix(
     data = c(0, 0, 1, 0, 1, 1, 0, 1, 0, 0),
     ncol = 2, byrow = TRUE
